@@ -9,8 +9,7 @@ use std::io::BufWriter;
 #[test]
 fn fgb_to_geojson() -> Result<()> {
     let mut filein = BufReader::new(File::open("tests/data/countries.fgb")?);
-    let mut fgb = FgbReader::open(&mut filein)?;
-    fgb.select_bbox(8.8, 47.2, 9.5, 55.3)?;
+    let mut fgb = FgbReader::open(&mut filein)?.select_bbox(8.8, 47.2, 9.5, 55.3)?;
     let json = fgb.to_json()?;
     assert_eq!(
         &json[0..215],
@@ -25,8 +24,10 @@ fn fgb_to_geojson() -> Result<()> {
 #[allow(dead_code)]
 async fn http_fbg_to_json() -> Result<()> {
     let url = "https://flatgeobuf.org/test/data/countries.fgb";
-    let mut fgb = HttpFgbReader::open(url).await?;
-    fgb.select_bbox(8.8, 47.2, 9.5, 55.3).await?;
+    let mut fgb = HttpFgbReader::open(url)
+        .await?
+        .select_bbox(8.8, 47.2, 9.5, 55.3)
+        .await?;
 
     let mut fout = BufWriter::new(File::create("countries.json")?);
     let mut json = GeoJsonWriter::new(&mut fout);
